@@ -26,17 +26,18 @@ redis['ex']=0  #过期时间 （秒）
 
 #缓存配置
 cache={}
-cache['type']='File' #驱动方式 支持 File Redis
+cache['type']='File' #驱动方式 支持 File Redis Python
 cache['path']='runtime/cachepath' #缓存保存目录 
 cache['expire']=120 #缓存有效期 0表示永久缓存
 cache['host']=redis['host'] #Redis服务器地址
 cache['port']=redis['port'] #Redis 端口
 cache['password']=redis['password'] #Redis登录密码
 cache['db']=1 #Redis数据库    注：Redis用1或2或3等表示
+cachevalue={}
 
 # session配置
 session={}
-session['type']='File' #session 存储类型  支持 file、Redis
+session['type']='File' #session 存储类型  支持 file、Redis、Python
 session['path']='runtime/session' #session缓存目录
 session['expire']=86400 #session默认有效期 该时间是指session在服务的保留时间，通常情况下浏览器上会保留该值的10倍
 session['prefix']="KCW" # SESSION 前缀
@@ -100,7 +101,7 @@ email['recNick']='' #默认收件人昵称
 
 kcweb={}
 kcweb['name']='kcweb'                             #项目的名称
-kcweb['version']='4.12.5'							#项目版本
+kcweb['version']='4.13.2'							#项目版本
 kcweb['description']=''       #项目的简单描述
 kcweb['long_description']=''     #项目详细描述
 kcweb['license']='MIT'                    #开源协议   mit开源
