@@ -46,6 +46,14 @@ class mongo:
         "获取mongodb链接实例"
         self.__setconn()
         return self.__tabobj
+    __order=None
+    def order(self,order):
+        """设置排序
+        
+        order [('_id', -1)]
+        """
+        self.__order=order
+        return self
     def select(self,id=None):
         """查询所有文档
 
@@ -57,9 +65,10 @@ class mongo:
             self.where('_id',id)
         lists=[]
         if self.__field:
-            arr=self.__tabobj.find(self.__where,self.__field)
+            arr=self.__tabobj.find(self.__where,self.__field,sort=self.__order)
         else:
-            arr=self.__tabobj.find(self.__where)
+            arr=self.__tabobj.find(self.__where,sort=self.__order)
+        print(self.__order)
         if self.__limit:
             if self.__limit[1]:
                 arr.limit(self.__limit[1])
@@ -209,6 +218,7 @@ class mongo:
         mongo.__field={}
         mongo.__where={}
         mongo.__table=None
+        mongo.__order=None
     __where={}
     def where(self,where = None,*wheres):
         """设置过滤条件  
