@@ -16,7 +16,12 @@ class model_kcweb_task(model.model):
         "code":model.dbtype.int(LEN=11,DEFAULT=2),              #状态码 0成功 1失败 2等待中 3正在执行  4完成
         "msg":model.dbtype.text(),                              #状态描述
         "error":model.dbtype.text(),                            #异常信息
-        "addtime":model.dbtype.int(LEN=11,DEFAULT=0)            #添加时间
+        "start":model.dbtype.int(LEN=11,DEFAULT=0),             #进度条起始值
+        "end":model.dbtype.int(LEN=11,DEFAULT=100),               #进度条结束值
+        "starts":model.dbtype.varchar(LEN=11,DEFAULT=0),             #每秒钟进度条起始值增加多少
+        "addtime":model.dbtype.int(LEN=11,DEFAULT=0),            #添加时间
+        "endtime":model.dbtype.int(LEN=11,DEFAULT=0),            #结束时间
+        "updtime":model.dbtype.int(LEN=11,DEFAULT=0)            #更新时间
     }
 class Queues():
     __globalqueue=None
@@ -45,29 +50,62 @@ class Queues():
                     try:
                         value['target'](*value['args'])
                     except Exception as e:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,"msg":"失败","error":str(e)})
+                        import traceback
+                        print(traceback.print_exc())
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,'endtime':int(time.time()),'updtime':int(time.time()),"msg":"失败","error":str(e)})
                     else:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"msg":"执行完成"})
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"start":100,'endtime':int(time.time()),'updtime':int(time.time()),"msg":"执行完成"})
                 else:
                     try:
                         value['target']()
                     except Exception as e:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,"msg":"失败","error":str(e)})
+                        import traceback
+                        print(traceback.print_exc())
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":1,'endtime':int(time.time()),'updtime':int(time.time()),"msg":"失败","error":str(e)})
                     else:
-                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"msg":"执行完成"})
+                        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"start":100,'endtime':int(time.time()),'updtime':int(time.time()),"msg":"执行完成"})
             else:
                 time.sleep(1)
-    def insert(target,args=None,title="默认任务",describes="",msg='等待中',taskid=None): #add_queue
+    def delhist():
+        """清除任务历史记录(包括 成功的 失败的 已完成的)"""
+        return kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("code","in",0,1,4).delete()
+    def setstart(taskid,start=1):
+        """设置进度条位置
+        
+        start 支持1到99的整数
+        """
+        arr=kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid",taskid).find()
+        if arr:
+            start=int(start)
+            if start>=1 and start <=99:
+                dqsjc=int(time.time())-arr['updtime'] #当前时间差
+                if dqsjc>=1:
+                    starts=round(float((start-arr['start'])/dqsjc),2)
+                    kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid",taskid).update({"start":start,'starts':starts,'updtime':int(time.time())})
+                return True
+            else:
+                return False
+        else:
+            return False
+    def insert(target,args=None,title="默认任务",describes="",msg='等待中',taskid=None,start=0,updtime=0): #add_queue
         """添加队列
         
         target 方法名  必须
 
-        args 方法参数 非必须  如
+        args 方法参数 非必须  如 (参数1,参数2)
 
         title 任务名称
 
         describes 任务描述
 
+        msg 状态描述
+
+        taskid 任务id
+
+        start 进度条开始位置 （建议1到50）
+
+        updtime 进度条更新时间
+
         return taskid
         """
         Queues.start()
@@ -76,7 +114,10 @@ class Queues():
             m = hashlib.md5()
             m.update((str(ttt)+str(random.randint(100000,999999))).encode(encoding='utf-8'))
             taskid=m.hexdigest()
-        task={"taskid":taskid,"title":title,"describes":describes,"code":2,"msg":msg,"error":"","addtime":ttt}
+        end=100
+        if not updtime:
+            updtime=ttt
+        task={"taskid":taskid,"title":title,"describes":describes,"code":2,"msg":msg,"error":"","start":start,"end":end,"addtime":ttt,'starts':0,'endtime':0,'updtime':updtime}
         key={"target":target,"args":args,"task":task}
         kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").insert(task)
         Queues.__globalqueue.put(key)
@@ -106,7 +147,14 @@ class Queues():
 
         return dict
         """
-        return kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").field("taskid,title,describes,code,msg,error,addtime").where("taskid",taskid).find()
+        arr=kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid",taskid).find()
+        if arr:
+            dqsjc=arr['updtime']-arr['addtime']
+            if dqsjc and arr['start']>=1:
+                arr['starts']=round(arr['start']/dqsjc,2)
+            else:
+                arr['starts']=round(arr['starts'],2)
+        return arr
     def iscomplete():
         """判断对列中的任务是否全部执行完成
         
